==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ia.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Assistente del prime execution",
    "Add your profile information! For example your email is needed to reset your password." : "Adde tu information de profilo! Per exemplo, tu adresse de e-posta es necessari pro reinitialisar tu contrasigno.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adde tu information de profilo! Assigna un pictura de profilo e tu nomine complete pro haber un recognition plus facile trans tote functionalitates.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adde tu information de profilo! Assigna tu nomine complete pro un recognition plus facile trans tote functionalitates.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adde tu information de profilo! Assigna un pictura de profilo pro un recognition plus facile trans tote functionalitates.",
    "Get the apps to sync your files" : "Obtene le applicationes pro synchronisar tu files",
    "Desktop client" : "Cliente de Scriptorio",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "Access files via WebDAV" : "Accede a files via WebDAV",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accede e comparti tu files, calendarios, contactos, e-posta e plus desde qualcunque apparato, sub tu terminos",
    "Connect your desktop apps to %s" : "Connecte tu application de scriptorio a %s",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Il ha plus informationes in le <a target=\"_blank\" href=\"%s\">documentation</a> e in nostre <a target=\"_blank\" href=\"%s\">sito web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Si tu ama Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud es un excellente software de codice aperte pro synchronisar e compartir tu files. Tu pote obtener lo gratis de https://nextcloud.com\"> recommenda lo a tu amicos</a> e <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribue in retorno</a>!",
    "Connect your Calendar" : "Connecte tu Calendario",
    "Connect your Contacts" : "Connecte tu Contactos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/ia.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Assistente del prime execution",
    "Add your profile information! For example your email is needed to reset your password." : "Adde tu information de profilo! Per exemplo, tu adresse de e-posta es necessari pro reinitialisar tu contrasigno.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Adde tu information de profilo! Assigna un pictura de profilo e tu nomine complete pro haber un recognition plus facile trans tote functionalitates.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Adde tu information de profilo! Assigna tu nomine complete pro un recognition plus facile trans tote functionalitates.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Adde tu information de profilo! Assigna un pictura de profilo pro un recognition plus facile trans tote functionalitates.",
    "Get the apps to sync your files" : "Obtene le applicationes pro synchronisar tu files",
    "Desktop client" : "Cliente de Scriptorio",
    "Android app" : "Application Android",
    "iOS app" : "Application iOS",
    "Connect your desktop apps to %s" : "Connecte tu application de scriptorio a %s",
    "Access files via WebDAV" : "Accede a files via WebDAV",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Accede e comparti tu files, calendarios, contactos, e-posta e plus desde qualcunque apparato, sub tu terminos",
    "Connect your Calendar" : "Connecte tu Calendario",
    "Connect your Contacts" : "Connecte tu Contactos",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Il ha plus informationes in le <a target=\"_blank\" href=\"%s\">documentation</a> e in nostre <a target=\"_blank\" href=\"%s\">sito web</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Si tu ama Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud es un excellente software de codice aperte pro synchronisar e compartir tu files. Tu pote obtener lo gratis de https://nextcloud.com\"> recommenda lo a tu amicos</a> e <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribue in retorno</a>!"
},
"nplurals=2; plural=(n != 1);");
